==> WebStore_2.8.1_estable.zip: core/classes/Familia.php <==
<?php
/*
	Clase Familia
	@version 1.0
*/

class SuperFamilia extends Objeto{
	public static $nombreTabla = 'familia';
	public static $alias = 'fam';
	public static $campos_tabla = array(['nombre']);
    function __construct($codigo_familia = NULL){
		$idioma = WSLocale::$idioma;
        $codigo_familia = NULL;
		$filaFamilia = NULL;
    }
    function __destruct(){
        
    }
	//Aquellas tablas "simples" no tienen que cargar ni campos ni nombre de manera especial, lo hacen con la función base
	/*
    public static function getCampos(){
		self::$nombreTabla = strtolower(get_called_class());
		self::getTablaRelacionada();
		//Una vez que tenemos el nombre de la tabla, vamos a obtener los campos de la misma y los nombres para la selec
		if (self::$nombreTabla != ''){
			//include('comunes/diccionario/diccionario.php');
			self::$campos_tabla = BaseDatos::$dictionary->{self::$nombreTabla . 'Campos'};
			self::$camposSelect = 
				BaseDatos::dameCamposAlias(BaseDatos::$dictionary->{self::$nombreTabla . 'Campos'}, self::getAlias()) . ' ';
		}
		return(self::$camposSelect);
	}
	
	public static function getNombreTabla(){
		$idioma = WSLocale::$idioma;
		//Incluimos los globals para coger el valor del idioma:
		//include('comunes/globals.php');
		self::$nombreTabla = strtolower(get_called_class());
		self::getTablaRelacionada();
		//Vamos a simplificar, cogemos el nombre de la tabla usando la función de la clase padre:
		self::$nombreTabla = self::$nombreTabla . ' `' .  self::getAlias() . '`  ';
		return(self::$nombreTabla);
	}
	*/
	public static function getWhereTabla(){
		$argumentos = func_get_args();
		$codigo_familia = isset($argumentos[0]) ? $argumentos[0] : NULL;
		$limitar = isset($argumentos[1]) ? $argumentos[1] : true;
		
		//include('comunes/globals.php');
		self::$whereSelect = '';
		if ($codigo_familia != NULL) {
			self::$whereSelect = ' `' . self::getAlias() . '`.`codigo` = "' . $codigo_familia . '" OR `' .  self::getAlias() . '`.`ean` = "' . $codigo_familia . '" ';
		}
		
		if ($limitar){
			self::$whereSelect .= ' LIMIT 0,1 ';
		}
		return(self::$whereSelect);
	}
	
}
?>

==> WebStore_2.8.3_estable.zip: core/classes/Familia.php <==
<?php
/*
	Clase Familia
	@version 1.0
*/

class SuperFamilia extends Objeto{
	public static $nombreTabla = 'familia';
	public static $alias = 'fam';
	public static $campos_tabla = array(['nombre']);
    function __construct($codigo_familia = NULL){
		$idioma = WSLocale::$idioma;
        $codigo_familia = NULL;
		$filaFamilia = NULL;
    }
    function __destruct(){
        
    }
	//Aquellas tablas "simples" no tienen que cargar ni campos ni nombre de manera especial, lo hacen con la función base
	/*
    public static function getCampos(){
		self::$nombreTabla = strtolower(get_called_class());
		self::getTablaRelacionada();
		//Una vez que tenemos el nombre de la tabla, vamos a obtener los campos de la misma y los nombres para la selec
		if (self::$nombreTabla != ''){
			//include('comunes/diccionario/diccionario.php');
			self::$campos_tabla = BaseDatos::$dictionary->{self::$nombreTabla . 'Campos'};
			self::$camposSelect = 
				BaseDatos::dameCamposAlias(BaseDatos::$dictionary->{self::$nombreTabla . 'Campos'}, self::getAlias()) . ' ';
		}
		return(self::$camposSelect);
	}
	
	public static function getNombreTabla(){
		$idioma = WSLocale::$idioma;
		//Incluimos los globals para coger el valor del idioma:
		//include('comunes/globals.php');
		self::$nombreTabla = strtolower(get_called_class());
		self::getTablaRelacionada();
		//Vamos a simplificar, cogemos el nombre de la tabla usando la función de la clase padre:
		self::$nombreTabla = self::$nombreTabla . ' `' .  self::getAlias() . '`  ';
		return(self::$nombreTabla);
	}
	*/
	public static function getWhereTabla(){
		$argumentos = func_get_args();
		$codigo_familia = isset($argumentos[0]) ? $argumentos[0] : NULL;
		$limitar = isset($argumentos[1]) ? $argumentos[1] : true;
		
		//include('comunes/globals.php');
		self::$whereSelect = '';
		if ($codigo_familia != NULL) {
			self::$whereSelect = ' `' . self::getAlias() . '`.`codigo` = "' . $codigo_familia . '" OR `' .  self::getAlias() . '`.`ean` = "' . $codigo_familia . '" ';
		}
		
		if ($limitar){
			self::$whereSelect .= ' LIMIT 1 ';
		}
		return(self::$whereSelect);
	}
	
}
?>
